/* Albert's solution to the Type Check problem.
 */

#include <iostream>
#include <string>
#include <vector>
#include <map>
#include <sstream>

using namespace std;

enum type { BOO, NAT, STR, ERR };   // ERR stands for type error

// a type rule for an operator
struct typerule
{
  int nparam;                       // number of parameters
  typerule(int n) : nparam(n) {}
  // infer() examines parameter types and returns the appropriate result type
  // it returns ERR if the parameters are no good
  virtual type infer(vector<type> &param) = 0;
};

// the kind of type rule that demands exact match
struct simple_typerule : public typerule
{
  type result;
  vector<type> param;
  simple_typerule(type r, type op) : typerule(1), result(r)
  {
    param.push_back(op);
  }
  simple_typerule(type r, type op1, type op2) : typerule(2), result(r)
  {
    param.push_back(op1);
    param.push_back(op2);
  }
  simple_typerule(type r, type op1, type op2, type op3) : typerule(3), result(r)
  {
    param.push_back(op1);
    param.push_back(op2);
    param.push_back(op3);
  }
  type infer(vector<type> &p)
  {
    if (p == param) return result; else return ERR;
  }
};

// two polymorphic type rules
// this one is for equality: (X,X)->BOO
struct equal_typerule : typerule
{
  equal_typerule() : typerule(2) {}
  type infer(vector<type> &p)
  {
    if (p[0] == p[1] && p[0] != ERR) return BOO; else return ERR;
  }
};
// one is for cond: (BOO,X,X)->X
struct cond_typerule : typerule
{
  cond_typerule() : typerule(3) {}
  type infer(vector<type> &p)
  {
    if (p[0] == BOO && p[1] == p[2] && p[1] != ERR) return p[1];
    else return ERR;
  }
};

// the database of operators and their type rules
map<string, typerule*> rulebase;
// need initialization code:
void init_rulebase()
{
  rulebase["not"] = new simple_typerule(BOO, BOO);
  rulebase["len"] = new simple_typerule(NAT, STR);
  rulebase["null"] = new simple_typerule(BOO, STR);
  rulebase["+"] = new simple_typerule(NAT, NAT, NAT);
  rulebase["*"] = new simple_typerule(NAT, NAT, NAT);
  rulebase["&&"] = new simple_typerule(BOO, BOO, BOO);
  rulebase["||"] = new simple_typerule(BOO, BOO, BOO);
  rulebase["="] = new equal_typerule();
  rulebase["<="] = new simple_typerule(BOO, NAT, NAT);
  rulebase["++"] = new simple_typerule(STR, STR, STR);
  rulebase["cond"] = new cond_typerule();
  rulebase["sub"] = new simple_typerule(STR, STR, NAT, NAT);
}

// type rules of atoms
type atom_type(string s)
{
  char f = s[0];
  if (f == 't' || f == 'f') return BOO;
  else if ('0' <= f && f <= '9') return NAT;
  else return STR;
}

// Now the recursion of reading expressions and checking types
type typecheck(istringstream &expr)
{
  string token;
  expr >> token;
  map<string, typerule*>::iterator r = rulebase.find(token);
  if (r == rulebase.end()) {
    // token is an atom
    return atom_type(token);
  }
  else {
    // token is an operator - get and process operands, then apply type rule
    typerule *rule = (*r).second;
    int n = rule->nparam;
    vector<type> param(n);
    for (int i = 0; i < n; ++i) {
      param[i] = typecheck(expr);
    }
    return rule->infer(param);
  }
}

int main()
{
  init_rulebase();
  int N;
  string line;
  cin >> N;
  getline(cin, line);
  for (int i = 0; i < N; ++i) {
    getline(cin, line);
    istringstream expr(line);
    cout << (typecheck(expr) == ERR ? "no" : "yes") << '\n';
  }
  return 0;
}
